@@ -478,19 +478,6 @@ mllm:
         from .subtitles import translate
         translate(subtitles_file=srt_name)
 
-    @staticmethod
-    def ocr_server():
-        os.system("python -m sparrow.mllm.ocr")
-
-    @staticmethod
-    def ocr():
-        from sparrow import relp
-        os.system(f"streamlit run {relp('./mllm/ocr_web.py')} --server.port 27080")
-
-    @staticmethod
-    def prompt():
-        from sparrow import relp
-        os.system(f"streamlit run {relp('./prompts/demo.py')} --server.port 27081 --server.maxUploadSize=1000")
 
     @staticmethod
     def test_torch():
@@ -552,10 +539,16 @@ Host {rsa_name}
                            Frames will be saved in '{out_dir}/{video_filename}/'.
         """
         from sparrow.dedup.video import VideoFrameDeduplicator
-        import cv2  # Import OpenCV
         from pathlib import Path  # Import Path
         from sparrow.performance._measure_time import MeasureTime # For timing
 
+        # 延迟导入 cv2
+        try:
+            import cv2
+        except ImportError:
+            print("未检测到 opencv-python (cv2) 库。请先安装：pip install opencv-python")
+            return
+
         mt = MeasureTime().start()
 
         try:
@@ -575,9 +568,7 @@ Host {rsa_name}
             count = dedup.process_and_save_unique_frames(video_path, out_dir)
             mt.show_interval(f"Completed processing. Saved {count} frames.") # Use simplified message
         except Exception as e:
-            # Error messages are printed inside the method, just log completion time if needed
-             print(f"Operation failed: {e}") # Optionally print error here as well
-             # mt.show_interval("Operation failed.")
+            print(f"Operation failed: {e}")
 
     @staticmethod
     def frames_to_video(frames_dir: str, output_video: str = None, fps: float = 15.0, codec: str = 'mp4v', use_av: bool = False):
